# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['django_processinfo',
 'django_processinfo.migrations',
 'django_processinfo.utils']

package_data = \
{'': ['*'],
 'django_processinfo': ['templates/admin/django_processinfo/*',
                        'templates/django_processinfo/*',
                        'templates/django_processinfo/includes/*']}

install_requires = \
['Django']

entry_points = \
{'console_scripts': ['publish = django_processinfo.publish:publish',
                     'update_rst_readme = '
                     'django_processinfo.publish:update_readme']}

setup_kwargs = {
    'name': 'django-processinfo',
    'version': '1.1.0',
    'description': 'Django application to collect information about the running server processes.',
    'long_description': '==================\ndjango-processinfo\n==================\n\nA reuseable Django application for collecing information about the running server processes.\nWe try to cause as little additional overhead: django-processinfo creates most of the time only one database query to update the data.\n\nThe most important data that django-processinfo will be captured:\n\n* Process statistics:\n\n    * process PID, start time, life times\n\n    * Number of average/max living processes\n\n    * min/average/max response times\n\n    * Total request/exceptions count\n\n* Memory statistics:\n\n    * min/average/max memory usage (VmRSS, VmPeak)\n\n* System informations:\n\n    * System memory usage\n\n    * Swap usage\n\n    * load average\n\ndjango-processinfo splits some of these data per SITE_ID, so you can see e.g. which site is mostly used.\n\nWhat is it not:\n\n* track user actions\n\n* collect infos which are found in e.g. apache.log\n\n* Its not a sourcecode profiler (read `https://code.djangoproject.com/wiki/ProfilingDjango <https://code.djangoproject.com/wiki/ProfilingDjango>`_)\n\nmore info: `https://www.python-forum.de/viewtopic.php?f=6&t=27168 <https://www.python-forum.de/viewtopic.php?f=6&t=27168>`_ (de)\n\n----------\nlimitation\n----------\n\nThis only works, if **/proc/$$/status** exists. So only on unix/linux like platforms, yet.\n\n----\nTODO\n----\n\nAdd unittests\n\n-----------\nscreenshots\n-----------\n\nHere `some screenshots (from v0.2 - 19.08.2011) <https://github.com/jedie/jedie.github.io/tree/master/screenshots/django-processinfo>`_ how it looks like:\n\n----\n\n|Screenshot 1|\n\n.. |Screenshot 1| image:: https://raw.githubusercontent.com/jedie/jedie.github.io/master/screenshots/django-processinfo/20110819_django-processinfo-1.png\n\n----\n\n|Screenshot 2|\n\n.. |Screenshot 2| image:: https://raw.githubusercontent.com/jedie/jedie.github.io/master/screenshots/django-processinfo/20110819_django-processinfo-2.png\n\n-------\ninstall\n-------\n\n1. install it e.g.:\n\n::\n\n    pip install django-processinfo\n\n2. add settings (see below)\n\n3. create tables (run syncdb)\n\n--------\nsettings\n--------\n\nadd this to your settings.py:\n\n::\n\n    import os\n    \n    import django_processinfo\n    \n    \n    INSTALLED_APPS = (\n    \t...\n    \t\'django_processinfo\',\n    \t...\n    )\n    \n    MIDDLEWARE = (\n        \'django_processinfo.middlewares.ProcessInfoMiddleware\',\n        ...\n    )\n    \n    # Put templates above admin contrib, e.g.:\n    TEMPLATE_DIRS = (\n    \t...\n        os.path.join(os.path.abspath(os.path.dirname(django_processinfo.__file__)), "templates/"),\n        ...\n    )\n    \n    # include app settings from ./django_processinfo/app_settings.py\n    from django_processinfo import app_settings as PROCESSINFO\n    \n    # Change settings like this:\n    PROCESSINFO.ADD_INFO = True\n\nProcessInfoMiddleware\n=====================\n\nThe **ProcessInfoMiddleware** can actually be inserted anywhere.\nHowever, it should be added far above. Thus, to capture everything.\n\nFor performance enhancement, you can put **ProcessInfoMiddleware** after **LocalSyncCacheMiddleware**.\nBut then, however, lacks statistical values on every cache hit!\n\napp settings\n============\n\nAvailable django-processinfo settings can you found in `./django_processinfo/app_settings.py <https://github.com/jedie/django-processinfo/blob/master/django_processinfo/app_settings.py>`_\n\n--------------\ndeveloper info\n--------------\n\ne.g.:\n\n::\n\n    ~$ git clone https://github.com/jedie/django-processinfo.git\n    ~$ cd django-processinfo\n    ~/django-processinfo$ make\n    help                 List all commands\n    install-poetry       install or update poetry\n    install              install PyInventory via poetry\n    update               update the sources and installation\n    lint                 Run code formatters and linter\n    fix-code-style       Fix code formatting\n    tox-listenvs         List all tox test environments\n    tox                  Run pytest via tox with all environments\n    tox-py36             Run pytest via tox with *python v3.6*\n    tox-py37             Run pytest via tox with *python v3.7*\n    tox-py38             Run pytest via tox with *python v3.8*\n    pytest               Run pytest\n    update-rst-readme    update README.rst from README.creole\n    publish              Release new version to PyPi\n    run-dev-server       Run the django dev server in endless loop.\n\nrun test project\n================\n\nThere exists a test project that can be easy run localy using the django dev. server and SQLite database.\nTo run this project, do this:\n\n::\n\n    ~/django-processinfo$ make run-dev-server\n\nYou must also setup a test user, call this:\n\n::\n\n    ~/django-processinfo$ ./manage.sh createsuperuser\n\n--------------------\nDjango compatibility\n--------------------\n\n+----------+------------------+------------------+\n| Version  | Python           | Django           |\n+==========+==================+==================+\n| >=v1.1.0 | 3.7,3.8,3.9,3.10 | 3.2,4.0,4.1      |\n+----------+------------------+------------------+\n| v0.9.0   | python 3         | django v2.2 LTS  |\n+----------+------------------+------------------+\n| v0.8.0   | python 3         | django v1.11 LTS |\n+----------+------------------+------------------+\n| v0.7.0   | python 2         | django v1.5      |\n+----------+------------------+------------------+\n| v0.6.1   | python 2         | django v1.4      |\n+----------+------------------+------------------+\n\n-------\nhistory\n-------\n\n* *dev* - `compare v1.1.0...master <https://github.com/jedie/django-processinfo/compare/v1.1.0...master>`_ \n\n    * TBC\n\n* `v1.1.0 - 16.08.2022 <https://github.com/jedie/django-processinfo/compare/v1.0.2...v1.1.0>`_ \n\n    * Test against Django 3.2, 4.0 and 4.1 with Python 3.7, 3.8, 3.9 and 3.10\n\n    * Modernize project setup\n\n* v1.0.2 - 09.12.2020 - `compare v1.0.1...v1.0.2 <https://github.com/jedie/django-processinfo/compare/v1.0.1...v1.0.2>`_ \n\n    * Bugfix "DataError: smallint out of range" on bigger PID numbers\n\n* v1.0.1 - 2.11.2020 - `compare v1.0.0...v1.0.1 <https://github.com/jedie/django-processinfo/compare/v1.0.0...v1.0.1>`_ \n\n    * Bugfix injected footer\n\n    * Fix/cleanup change list\n\n    * Bugfix test project ``manage.sh``\n\n    * cleanup test project\n\n* v1.0.0 - 1.11.2020 - `compare v0.9.0...v1.0.0 <https://github.com/jedie/django-processinfo/compare/v0.9.0...v1.0.0>`_ \n\n    * modernize project setup using poetry\n\n    * Add a test project\n\n    * Add tests\n\n    * upgrade code style\n\n* v0.9.0 - 26.02.2020 - `compare v0.8.0...v0.9.0 <https://github.com/jedie/django-processinfo/compare/v0.8.0...v0.9.0>`_ \n\n    * Updates for Django 2.2\n\n* v0.8.0 - 09.03.2018 - `compare v0.7.1...v0.8.0 <https://github.com/jedie/django-processinfo/compare/v0.7.1...v0.8.0>`_ \n\n    * Updates for Python v3 and Django 1.11\n\n* v0.7.1 - 20.08.2015 - `compare v0.6.3...v0.7.1 <https://github.com/jedie/django-processinfo/compare/v0.6.3...v0.7.1>`_ \n\n    * Changes for django 1.5 support\n\n    * change setup install_requires to Django v1.3.x - v1.5.x\n\n    * Bugfix in templates: missed i18n\n\n* v0.6.3 - 24.08.2012\n\n    * remove auto commit date from version\n\n* v0.6.2\n\n    * Auto cleanup ProcessInfo table to protect against overloading.\n\n    * Don\'t insert django-processinfo "time cost" info if response.status_code is not 200\n\n* v0.6.1\n\n    * Tested also with django v1.4\n\n    * change setup install_requires to Django v1.3.x - v1.4.x\n\n* v0.6.0\n\n    * Add "Reset all data" in object tools.\n\n    * Make "Remove dead PIDs" and "Reset all data" available on both admin pages.\n\n* v0.5.2\n\n    * `Bugfix if no SWAP used. <https://github.com/jedie/django-processinfo/issues/4>`_\n\n* v0.5.1\n\n    * Add "Remove dead PIDs" as admin view in "Process statistics" object tools (top, right, grey links)\n\n* v0.5.0\n\n    * Model changes: Please recreate tables, e.g.: ``./manage.py reset django_processinfo`` \n\n    * New: Display some static system informations (uname, domain name, ip adress, python version, sys.prefix)\n\n    * New: current living processes (also per site)\n\n    * display sum of user/system mode time\n\n* v0.4.1\n\n    * Bugfix for UnicodeEncodeError in setup: Use new solution, see: `https://code.google.com/p/python-creole/wiki/UseInSetup <https://code.google.com/p/python-creole/wiki/UseInSetup>`_\n\n* v0.4\n\n    * Bugfix with "Total created processes"\n\n    * Display "Process lifetime"\n\n* v0.3.0\n\n    * Display some system information from /proc/meminfo and \'load average\'\n\n    * Many Bugfixes\n\n* v0.2.0\n\n    * Many things changes! Recreate tables, e.g: ``./manage.py reset django_processinfo`` \n\n* v0.1.0\n\n    * first Version\n\n--------\nDonation\n--------\n\n* `paypal.me/JensDiemer <https://www.paypal.me/JensDiemer>`_\n\n* `Flattr This! <https://flattr.com/submit/auto?uid=jedie&url=https%3A%2F%2Fgithub.com%2Fjedie%2Fdjango-reversion-compare%2F>`_\n\n* Send `Bitcoins <http://www.bitcoin.org/>`_ to `1823RZ5Md1Q2X5aSXRC5LRPcYdveCiVX6F <https://blockexplorer.com/address/1823RZ5Md1Q2X5aSXRC5LRPcYdveCiVX6F>`_\n\n-----\nlinks\n-----\n\n+--------+---------------------------------------------------+\n| GitHub | `https://github.com/jedie/django-processinfo`_    |\n+--------+---------------------------------------------------+\n| PyPi   | `http://pypi.python.org/pypi/django-processinfo`_ |\n+--------+---------------------------------------------------+\n\n.. _https://github.com/jedie/django-processinfo: https://github.com/jedie/django-processinfo\n.. _http://pypi.python.org/pypi/django-processinfo: http://pypi.python.org/pypi/django-processinfo\n\ncontact\n=======\n\nCome into the conversation, besides the github communication features:\n\n+---------+--------------------------------------------------------+\n| Forum   | `http://www.pylucid.org/en/forum/10/`_                 |\n+---------+--------------------------------------------------------+\n| IRC     | #pylucid on freenode.net (Yes, the PyLucid channel...) |\n+---------+--------------------------------------------------------+\n| webchat | `http://webchat.freenode.net/?channels=pylucid`_       |\n+---------+--------------------------------------------------------+\n\n.. _http://www.pylucid.org/en/forum/10/: http://www.pylucid.org/en/forum/10/\n.. _http://webchat.freenode.net/?channels=pylucid: http://webchat.freenode.net/?channels=pylucid\n\n------------\n\n``Note: this file is generated from README.creole 2022-08-16 18:56:10 with "python-creole"``',
    'author': 'JensDiemer',
    'author_email': 'git@jensdiemer.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0.0',
}


setup(**setup_kwargs)
